// $Id: $
//
// Class Ex03MCApplication
// ----------------------- 
// Implementation of the TVirtualMCApplication
//
// by Ivana Hrivnacova, 5.4.2002

#ifndef EX03_MC_APPLICATION_H
#define EX03_MC_APPLICATION_H

#include <TVirtualMCApplication.h>
#include <TVirtualMCStack.h>

class TGeoVolume;

class Ex03MCApplication : public TVirtualMCApplication
{
  public:
    Ex03MCApplication(const char *name, const char *title);
    Ex03MCApplication();
    virtual ~Ex03MCApplication();
  
    // static access method
    static Ex03MCApplication* Instance(); 

    // methods
    void InitMC(const char *setup);
    void RunMC(Int_t nofEvents);
    void FinishRun();
 
    virtual void ConstructGeometry();
    virtual void InitGeometry();
    virtual void GeneratePrimaries();
    virtual void BeginEvent();
    virtual void BeginPrimary();
    virtual void PreTrack();
    virtual void Stepping();
    virtual void PostTrack();
    virtual void FinishPrimary();
    virtual void FinishEvent();
    
    virtual Double_t TrackingRmax() const;
    virtual Double_t TrackingZmax() const;
    virtual void Field(const Double_t* x, Double_t* b) const;

  private:
    // methods
    TGeoVolume* BuildRootGeometry() const;
  
    // data members
    TVirtualMCStack*  fStack;
    Int_t  fImedAr;
    Int_t  fImedAl;
    Int_t  fImedPb;

  ClassDef(Ex03MCApplication,1)  //Interface to MonteCarlo application
};

// inline functions

inline Ex03MCApplication* Ex03MCApplication::Instance()
{ return (Ex03MCApplication*)(TVirtualMCApplication::Instance()); }

#endif //EX03_MC_APPLICATION_H

